# Copyright 2004, Rick Wilson 
#
# THIS SOFTWARE IS PROVIDED "AS IS" AND WITHOUT ANY EXPRESS OR
# IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED
# WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
#
# Name :          xlines.rb 1.0
# Description :   Convert selected edges to construction lines
# Author :        Rick Wilson
# Usage :         1.	Install into the plugins directory or into the 
#				Plugins/examples directory and manually load from the
#				ruby console "load 'examples/xlines.rb'" 
#                 2.	Select "Convert to xLine" from the context menu after
#				selecting an edge.
# Date :          2008-01-21
# Type :          Tool
# History:
#     1.2 (2006-07-06) - Modified by D. Bur, Lines stipple supported. Back converter integrated.
#			1.1 (2008-01-21) - updated to put resultant geometry in the same entity space as the original
#			1.0 (2004-08-20) - first version
# 
require 'sketchup.rb'

def xLine
	model=Sketchup.active_model
	ents=model.active_entities
	sel=model.selection
	lines=[]
  $xline_style = "-" if not $xline_style
	model.start_operation "Convertir en guides"
  dropdown=[[". . . . . .","- - - - - -","_ _ _ _ _ _","- . - . - . -"].join("|")]
  prompt=["Police de trait: "]
  value=[$xline_style]
  result=inputbox prompt, value, dropdown, "Convertion"
  return if not result
  $xline_style=result[0]
  case $xline_style
     when ". . . . . ."
      stipp = "."
     when "- - - - - -"
      stipp = "-"
     when "_ _ _ _ _ _"
      stipp = "_"
     when "- . - . - . -"
      stipp = "-.-"
  end
      
	for e in sel
		if e.class == Sketchup::Edge
			guide=ents.add_cline(e.start.position,e.end.position)
      guide.stipple=stipp
			lines.push(e)
		end
	end
	if not lines.empty?
		for e in lines
			e.erase! if e.valid? #if e.faces.empty?
 		end
	end
	model.commit_operation
end

def xLine_validate_selection
	Sketchup.active_model.selection.each {|e| return true if e.class == Sketchup::Edge}
	return nil
end

def line_validate_selection
	Sketchup.active_model.selection.each {|e| return true if e.class == Sketchup::ConstructionLine}
	return nil
end

def xLine2Line
	model=Sketchup.active_model
	ents=model.entities
	sel=model.selection
	clines=[]
	model.start_operation "Convertir en lignes"
	for e in sel
		if e.class == Sketchup::ConstructionLine
			lstart=e.start if e.start
			lend=e.end if e.end
			ents.add_line(lstart,lend) if e.start and e.end
			clines.push(e)
		end
	end
	if not clines.empty?
		for e in clines
			e.erase! if e.valid? and e.start and e.end
 		end
	end
	model.commit_operation
end


if( not file_loaded?("fr_lines_converter.rb") )
	UI.add_context_menu_handler do |menu|
		if xLine_validate_selection
			menu.add_separator
			menu.add_item("Convertir lignes en guides") { xLine }
		end
    if line_validate_selection
			menu.add_separator
			menu.add_item("Convert guides en lignes") { xLine2Line }
		end
	end
end

#-----------------------------------------------------------------------------
file_loaded("fr_lines_converter.rb")
